# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

version = '0.4.8'

setup(
    name='manifest-ingest',
    version=version,

    description='Download a project JSON manifest and its media files via SFTP, HTTP or Amazon S3. This tool was developed for internal use on all X Studios interactive installations which need to have the ability to run "offline" when there is no active network connection.',
    long_description=long_description,

    url='https://bitbucket.org/xstudios/manifest-ingest',
    download_url='https://bitbucket.org/xstudios/manifest-ingest/get/%s.tar.gz' % version,
    author='Tim Santor',
    author_email='tsantor@xstudios.agency',

    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        "Environment :: Console",

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
    ],

    keywords='ftp manifest downloader',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'pysftp==0.2.8',  # Windows complains if it is > 0.2.9
        'paramiko>=2.2.1,<3',
        'requests>=2.18.1,<3',
        'six>=1.10.0,<2',
        'boto3>=1.4.4,<2',
    ],

    # If there are data files included in your packages that need to be
    # installed in site-packages, specify them here.  If using Python 2.6 or
    # less, then these have to be included in MANIFEST.in as well.
    include_package_data=True,

    package_data={},

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'manifest-ingest = manifest.main:run',
            'manifest-sftp = manifest.main:run',
            'manifest-http = manifest.main:run',
            'manifest-s3 = manifest.main:run',
        ],
    },
)
